@@ -305,12 +305,12 @@ glmc_vec2_make(const float * __restrict src, vec2 dest) {
 
 CGLM_EXPORT
 void
-glmc_vec2_reflect(vec2 I, vec2 N, vec2 dest) {
-  glm_vec2_reflect(I, N, dest);
+glmc_vec2_reflect(vec2 v, vec2 n, vec2 dest) {
+  glm_vec2_reflect(v, n, dest);
 }
 
 CGLM_EXPORT
 bool
-glmc_vec2_refract(vec2 I, vec2 N, float eta, vec2 dest) {
-  return glm_vec2_refract(I, N, eta, dest);
+glmc_vec2_refract(vec2 v, vec2 n, float eta, vec2 dest) {
+  return glm_vec2_refract(v, n, eta, dest);
 }
