@@ -39,6 +39,8 @@
 #include "test_cam_lh_zo.h"
 #include "test_cam_rh_no.h"
 #include "test_cam_rh_zo.h"
+#include "test_euler_to_quat_rh.h"
+#include "test_euler_to_quat_lh.h"
 
 #undef GLM
 #undef GLM_PREFIX
@@ -76,6 +78,8 @@
 #include "test_cam_lh_zo.h"
 #include "test_cam_rh_no.h"
 #include "test_cam_rh_zo.h"
+#include "test_euler_to_quat_rh.h"
+#include "test_euler_to_quat_lh.h"
 
 #undef GLM
 #undef GLM_PREFIX
